NAME

App::FilenameKeyValueUtils - CLIs for Filename::KeyValue

VERSION

This document describes version 0.003 of App::FilenameKeyValueUtils (from Perl distribution App-FilenameKeyValueUtils), released on 2026-05-29.

SYNOPSIS

DESCRIPTION

This distribution includes several utilities related to Filename::KeyValue:

1. modify-keyvalue-filename
2. normalize-keyvalue-filename
3. parse-keyvalue-filename
4. rename-add-keyvalue-filenames
5. rename-modify-keyvalue-filenames
6. rename-remove-keyvalue-filenames
7. rename-replace-keyvalue-filenames

HOMEPAGE

Please visit the project's homepage at https://metacpan.org/release/App-FilenameKeyValueUtils.

SOURCE

Source repository is at https://github.com/perlancar/perl-App-FilenameKeyValueUtils.

SEE ALSO

Filename::KeyValue

AUTHOR

perlancar <perlancar@cpan.org>

CONTRIBUTOR

perlancar <perlancar@gmail.com>

CONTRIBUTING

To contribute, you can send patches by email/via RT, or send pull requests on GitHub.

Most of the time, you don't need to build the distribution yourself. You can simply modify the code, then test via:

% prove -l

If you want to build the distribution (e.g. to try to install it locally on your system), you can install Dist::Zilla, Dist::Zilla::PluginBundle::Author::PERLANCAR, Pod::Weaver::PluginBundle::Author::PERLANCAR, and sometimes one or two other Dist::Zilla- and/or Pod::Weaver plugins. Any additional steps required beyond that are considered a bug and can be reported to me.

COPYRIGHT AND LICENSE

This software is copyright (c) 2026 by perlancar <perlancar@cpan.org>.

This is free software; you can redistribute it and/or modify it under the same terms as the Perl 5 programming language system itself.

BUGS

Please report any bugs or feature requests on the bugtracker website https://rt.cpan.org/Public/Dist/Display.html?Name=App-FilenameKeyValueUtils

When submitting a bug or request, please include a test-file or a patch to an existing test-file that illustrates the bug or desired feature.