NAME

App::MARC::Validator - Base class for marc-validator script.

SYNOPSIS

use App::MARC::Validator;

my $app = App::MARC::Validator->new;
my $exit_code = $app->run;

METHODS

new

my $app = App::MARC::Validator->new;

Constructor.

Returns instance of object.

run

my $exit_code = $app->run;

Run MARC validation command line application.

Returns 1 for error, 0 for success.

ERRORS

new():
        From Class::Utils::set_params():
                Unknown parameter '%s'.

DEPENDENCIES

App::MARC::Validator::Utils, Class::Utils, Data::MARC::Validator::Report, DateTime, English, Getopt::Std, IO::Barf, IO::Uncompress::AnyUncompress, List::Util, MARC::Batch, MARC::File::XML, MARC::Validator, MARC::Validator::Filter, Unicode::UTF8.

REPOSITORY

https://github.com/michal-josef-spacek/App-MARC-Validator

AUTHOR

Michal Josef Špaček mailto:skim@cpan.org

http://skim.cz

LICENSE AND COPYRIGHT

© 2025-2026 Michal Josef Špaček

BSD 2-Clause License

ACKNOWLEDGEMENTS

Development of this software has been made possible by institutional support for the long-term strategic development of the National Library of the Czech Republic as a research organization provided by the Ministry of Culture of the Czech Republic (DKRVO 2024–2028), Area 11: Linked Open Data.

VERSION

0.09