NAME

App::SortCopies - The copy sorter! (What did you expect?)

VERSION

Version 0.01

SYNOPSIS

This sorts a directory, in a non-recursive way.

Copies of files are moved to a ./copies folder created in the directory being sorted

sortcopies ~/path/to/dir_with_dupes

AUTHOR

Semandi <semandi@cpan.org>

BUGS

Please report any bugs or feature requests to bug-app-sortcopies at rt.cpan.org, or through the web interface at https://rt.cpan.org/NoAuth/ReportBug.html?Queue=App-SortCopies. I will be notified, and then you'll automatically be notified of progress on your bug as I make changes.

SUPPORT

You can find documentation for this module with the perldoc command.

perldoc App::SortCopies

You can also look for information at:

ACKNOWLEDGEMENTS

To all the foxes of the world...

LICENSE AND COPYRIGHT

This software is Copyright (c) 2026 by Semandi <semandi@cpan.org>.

This is free software, licensed under:

The Artistic License 2.0 (GPL Compatible)