NAME
App::karr::Cmd::Sync - Sync karr board with remote
VERSION
version 0.102
SYNOPSIS
karr sync
karr sync --pull
karr sync --push
DESCRIPTION
Synchronises the refs/karr/* namespace with the configured remote. Without flags it fetches the remote ref state and then pushes the local ref state back, pruning deleted refs so destructive restore operations can be mirrored correctly.
OPTIONS
--pullOnly fetches remote
refs/karr/*.--pushOnly pushes local
refs/karr/*state to the configured remote.
SEE ALSO
karr, App::karr, App::karr::Cmd::Board, App::karr::Cmd::Backup, App::karr::Cmd::Restore
SUPPORT
Issues
Please report bugs and feature requests on GitHub at https://github.com/Getty/p5-app-karr/issues.
IRC
Join #ai on irc.perl.org or message Getty directly.
CONTRIBUTING
Contributions are welcome! Please fork the repository and submit a pull request.
AUTHOR
Torsten Raudssus <torsten@raudssus.de>
COPYRIGHT AND LICENSE
This software is copyright (c) 2026 by Torsten Raudssus <torsten@raudssus.de> https://raudssus.de/.
This is free software; you can redistribute it and/or modify it under the same terms as the Perl 5 programming language system itself.