NAME
App::Envdoctor - Local-first consistency checker for environment variables
SYNOPSIS
envdoctor scan --dir .
DESCRIPTION
Reconciles the environment variables used in Perl source ($ENV{X}) against those defined in .env files, reporting variables that are used but never defined (error) and defined but never referenced (warning).
Nothing is uploaded and variable values are never printed.
SEE ALSO
App::Envdoctor::Scanner, https://github.com/arun-skg/envdoctor
LICENSE
MIT